@@ -113,7 +113,7 @@ L<Template::Declare::TagSet>.
 
 =head1 AUTHOR
 
-Agent Zhang E<lt>agentzh@gmail.comE<gt>
+Agent Zhang <agentzh@yahoo.cn>
 
 =head1 SEE ALSO
 
